@@ -95,7 +95,7 @@ class WaifuAioClient:
         return infos.get('url')
 
 
-    async def _fetchgallery(self, insert, delete):
+    async def _fetchgallery(self, insert, delete,token=None):
         """process the request for a specific tag and check if everything is correct."""
         params={}
         headers={}
@@ -105,7 +105,9 @@ class WaifuAioClient:
             params.update({'insert':','.join(insert)})
         if self.appname:
             headers={'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}'}
-        headers.update({'Authorization':f'Bearer {self.token}'})
+        if not token:
+            token=self.token
+        headers.update({'Authorization':f'Bearer {token}'})
         return await self._make_request(f"{APIBaseURL}fav/",'get',params=params,headers=None if not headers else headers)
 
     async def _fetchendpoints(self, full=False):
@@ -154,22 +156,19 @@ class WaifuAioClient:
         return data
 
     @requires_token
-    async def fav(self, insert: List[str]=None, delete: List[str]=None, newtoken: str=None):
+    async def fav(self, insert: List[str]=None, delete: List[str]=None, token: str=None):
         """Get your favorite gallery.""
 
         Kwargs:
             insert: A list of URL's that you want to add to your gallery in the same time.
             delete: A list of URL's that you want to remove from your gallery in the same time.
-            newtoken: The new token that you want to use instead of the one you passed to the Class, it will be kept in memory until you change again.
+            token: The token that will be use for this request only, this doesnt change the token you passed in the class.
         Returns:
             A dictionnary containing the json the API returned.
         Raises:
             APIException: If the API response contains an error.
         """
-        if newtoken:
-            self.token=newtoken
-        data = await self._fetchgallery(insert,delete)
-        return data
+        return await self._fetchgallery(insert,delete,token=token)
 
     async def endpoints(self, full=False):
         """Gets the API endpoints.
