@@ -27,7 +27,9 @@ APIBaseURL="https://api.waifu.im/"
 def requires_token(func):
     """A decorator used to check if the user passed a token before trying to use the fav method."""
     def wrapper(*args, **kwargs):
-        if args[0].token:
+        if kwargs['token']:
+            return func(*args,**kwargs)
+        elif args[0].token:
             return func(*args,**kwargs)
         raise NoToken
     return wrapper
\ No newline at end of file
